@@ -255,6 +255,9 @@ class BuildBlenderScene(RunAction):
     def runner_name_and_tags(self):
         return "Blender", []
     
+    def get_run_label(self):
+        return 'Build scene'
+    
     def allow_context(self, context):
         return context and context.endswith(".inline")
 
@@ -331,6 +334,9 @@ class BuildBlenderScene(RunAction):
 
 class BuildLayoutScene(BuildBlenderScene):
 
+    def get_run_label(self):
+        return 'Build layout scene'
+
     def extra_argv(self):
         # Get scene builder arguments
         frame_start = 101
@@ -458,6 +464,9 @@ class BuildBlockingScene(BuildBlenderScene):
     _shot = flow.Parent(3)
     _sequence = flow.Parent(5)
     
+    def get_run_label(self):
+        return 'Build blocking scene'
+    
     def extra_argv(self):
         # Get scene builder arguments
         anim_path = self._shot_data.get("anim_path", None)
@@ -498,10 +507,10 @@ class BuildBlockingScene(BuildBlenderScene):
         files = self._shot.departments.layout.files
 
         if "layout_blend" in files.mapped_names():
-            latest_revision = files["layout_blend"].get_head_revision(sync_status='Available')
+            latest_revision = files["layout_blend"].get_head_revision()
 
-        if (latest_revision is None):
-            msg = "<h2><font color=#D5000D>Layout file not available</font></h2>"
+        if (latest_revision is None or latest_revision.get_sync_status() != 'Available'):
+            msg = "<h2><font color=#D5000D>Last revision of layout file not available</font></h2>"
             buttons =  ["Cancel"]
         else:
             msg = "<h2>Configure animation shot</h2>"
@@ -535,7 +544,7 @@ class BuildBlockingScene(BuildBlenderScene):
             asset_number = dep.asset_number.get()
 
             if asset_type in ["chars", "props"]:
-                self._shot_data["assets_data"].append((dep.name(), path, asset_type, asset_number))
+                self._shot_data["assets_data"].append((dep.name(), path, asset_type + '_', asset_number))
             else:
                 self._shot_data["%s_path" % asset_type] = path
 
