@@ -54,6 +54,7 @@ class RiggingDepartment(Department):
 class Util(flow.Object):
 
     _util_map = flow.Parent()
+    _short_name = flow.Param(None)
     files = flow.Child(FileSystemMap)
     file_prefix = flow.Param('{util}').ui(
         hidden=True,
@@ -66,7 +67,11 @@ class Util(flow.Object):
 
     def get_default_contextual_edits(self, context_name):
         if context_name == 'settings':
-            return dict(util=self.name())
+            name = self._short_name.get()
+            if name is None:
+                name = self.name()
+
+            return dict(util=name)
 
 
 class UtilMap(flow.Map):
@@ -97,11 +102,16 @@ class SkinningUtils(UtilMap):
     _short_name = flow.Param("skinning")
 
 
-class RigModuleUtils(UtilMap):
+class RigModuleUtils(Util):
     
     _short_name = flow.Param("rigmod")
 
 
+class MiscUtils(Util):
+    
+    _short_name = flow.Param("misc")
+
+
 class Utils(flow.Object):
     
     skinning = flow.Child(SkinningUtils).ui(
@@ -112,6 +122,10 @@ class Utils(flow.Object):
         expanded=True,
         show_filter=True,
     )
+    miscellaneous = flow.Child(MiscUtils).ui(
+        expanded=True,
+        show_filter=True,
+    )
     file_prefix = flow.Param('utils').ui(
         hidden=True,
         editable=False,
